
# Slot: agent set




URI: [ks:agent_set](https://w3id.org/linkml/tests/kitchen_sink/agent_set)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Agent](Agent.md)

## Parents


## Children


## Used by

